import React from 'react'
import styled from 'styled-components'
import { Icon, th } from '@pubsweet/ui'

const Pagination = ({
  page,
  itemsPerPage,
  incrementPage,
  decrementPage,
  hasMore,
  maxLength,
}) => (
  <Root>
    <Showing>
      <span>Showing:</span>
      <span>{itemsPerPage}</span>
    </Showing>
    <Chevrons>
      <IconButton hide={page === 0} onClick={decrementPage}>
        <Icon primary size={3}>
          chevron-left
        </Icon>
      </IconButton>
      <span>
        {`${page * itemsPerPage + 1} to ${
          hasMore ? itemsPerPage * (page + 1) : maxLength
        }`}
      </span>
      <IconButton hide={!hasMore} onClick={incrementPage}>
        <Icon primary size={3}>
          chevron-right
        </Icon>
      </IconButton>
    </Chevrons>
  </Root>
)

export default Pagination

const Root = styled.div`
  align-items: center;
  display: flex;
`

const Chevrons = styled.div`
  display: flex;
  align-items: center;
`

const IconButton = styled.button`
  align-items: center;
  background-color: ${th('backgroundColor')};
  border: none;
  color: ${th('colorPrimary')};
  cursor: ${({ hide }) => (hide ? 'auto' : 'pointer')};
  display: flex;
  font-family: ${th('fontInterface')};
  font-size: ${th('fontSizeBaseSmall')};
  opacity: ${({ hide }) => (hide ? 0 : 1)};
  text-align: left;

  &:active,
  &:focus {
    outline: none;
  }
  &:hover {
    opacity: 0.7;
  }
`

const Showing = styled.div`
  align-items: center;
  display: flex;

  span:first-child {
    color: ${th('colorPrimary')};
    font-family: ${th('fontInterface')};
    font-size: ${th('fontSizeBaseSmall')};
    margin-right: 10px;
    text-align: left;
  }
  span:last-child {
    border: ${th('borderDefault')};
    padding: 2px 10px;
  }
`
