import { SubmissionError } from 'redux-form'
import { pick, map, omit, get } from 'lodash'

const generatePasswordHash = () =>
  Array.from({ length: 4 }, () =>
    Math.random()
      .toString(36)
      .slice(4),
  ).join('')

export const getRoleOptions = journal =>
  map(journal.roles, (value, key) => ({ label: value, value: key }))

export const setAdmin = values => {
  const newValues = { ...values }
  if (newValues.roles && newValues.roles.includes('admin')) {
    newValues.admin = true
  } else {
    newValues.admin = false
  }

  return {
    ...omit(newValues, ['role']),
    username: newValues.email,
    isConfirmed: false,
    passwordResetToken: generatePasswordHash(),
    password: 'defaultpass',
    editorInChief: newValues.role === 'editorInChief',
    handlingEditor: newValues.role === 'handlingEditor',
  }
}

export const parseUpdateUser = values => {
  const valuesToSave = [
    'admin',
    'firstName',
    'lastName',
    'affiliation',
    'title',
    'roles',
    'editorInChief',
    'handlingEditor',
  ]

  return pick(values, valuesToSave)
}

export const handleFormError = error => {
  const err = get(error, 'response')
  if (err) {
    const errorMessage =
      get(JSON.parse(err), 'error') || get(JSON.parse(err), 'message')
    throw new SubmissionError({
      _error: errorMessage || 'Something went wrong',
    })
  }
}
