import React from 'react'
import { required } from 'xpub-validators'
import styled, { css } from 'styled-components'
import { TextField, Menu, ValidatedField, Icon, th } from '@pubsweet/ui'

export const ValidatedTextField = ({
  label,
  name,
  isRequired,
  validators = [],
}) => {
  const v = [isRequired && required, ...validators].filter(Boolean)
  return (
    <ValidatedTextFieldRoot>
      <StyledLabel>{label}</StyledLabel>
      <ValidatedField component={TextField} name={name} validate={v} />
    </ValidatedTextFieldRoot>
  )
}

export const MenuItem = ({ label, name, options }) => (
  <MenuItemRoot data-test="country-selector-author">
    <StyledLabel>{label}</StyledLabel>
    <ValidatedField
      component={input => <Menu {...input} options={options} />}
      name={name}
      validate={[required]}
    />
  </MenuItemRoot>
)

export const Label = ({ label, value }) => (
  <LabelRoot>
    <span>{label}</span>
    <span>{value}</span>
  </LabelRoot>
)

export const DragHandle = () => (
  <DragHandleRoot>
    <Icon primary>chevron_up</Icon>
    <Icon primary size={3}>
      menu
    </Icon>
    <Icon primary>chevron_down</Icon>
  </DragHandleRoot>
)

// #region styled-components
const defaultText = css`
  color: ${th('colorText')};
  font-size: ${th('fontSizeBaseSmall')};
  font-family: ${th('fontReading')};
`

const ValidatedTextFieldRoot = styled.div`
  flex: 1;
  margin-right: 5px;
`

const MenuItemRoot = styled.div`
  flex: 1;
`

const StyledLabel = styled.span`
  ${defaultText};
  font-weight: 300;
  text-transform: uppercase;
`

const DragHandleRoot = styled.div`
  align-items: center;
  border-right: ${th('borderDefault')};
  cursor: move;
  display: flex;
  flex-direction: column;
  justify-content: center;
`

const LabelRoot = styled.div`
  display: flex;
  flex: 1;
  flex-direction: column;
  margin: ${th('subGridUnit')};
  width: ${({ width }) => `${width || 150}px`};

  span:first-child {
    ${defaultText};
    font-weight: 300;
    overflow: hidden;
    text-transform: uppercase;
    text-overflow: ellipsis;
    white-space: nowrap;
  }

  span:last-child {
    ${defaultText};
    font-weight: 600;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
  }
`
// #endregion
