import React from 'react'
import { th } from '@pubsweet/ui'
import { Tooltip } from 'react-tippy'
import styled, { ThemeProvider, withTheme } from 'styled-components'

const AuthorTooltip = ({
  authorName,
  email,
  affiliation,
  isSubmitting,
  isCorresponding,
  theme,
}) => (
  <ThemeProvider theme={theme}>
    <TooltipRoot>
      <TooltipRow>
        <AuthorName>{authorName}</AuthorName>
        {isSubmitting && <SpecialAuthor>Submitting Author</SpecialAuthor>}
        {isCorresponding &&
          !isSubmitting && <SpecialAuthor>Corresponding Author</SpecialAuthor>}
      </TooltipRow>
      <TooltipRow>
        <AuthorDetails>{email}</AuthorDetails>
      </TooltipRow>
      <TooltipRow>
        <AuthorDetails>{affiliation}</AuthorDetails>
      </TooltipRow>
    </TooltipRoot>
  </ThemeProvider>
)

const TooltipComponent = ({ children, ...rest }) => (
  <Tooltip arrow html={<AuthorTooltip {...rest} />} position="bottom">
    {children}
  </Tooltip>
)

export default withTheme(TooltipComponent)

// #region styled-components
const TooltipRoot = styled.div`
  align-items: flex-start;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: calc(${th('subGridUnit')}*2);
`

const TooltipRow = styled.div`
  align-items: center;
  display: flex;
  justify-content: flex-start;
  margin: ${th('subGridUnit')} 0;
`

const AuthorName = styled.span`
  color: ${th('colorSecondary')};
  font-family: ${th('fontHeading')};
  font-size: ${th('fontSizeBase')};
`

const AuthorDetails = styled.span`
  color: ${th('colorSecondary')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const SpecialAuthor = styled.span`
  background-color: ${th('colorBackground')};
  color: ${th('colorTextPlaceholder')};
  font-family: ${th('fontInterface')};
  font-size: ${th('fontSizeBaseSmall')};
  font-weight: bold;
  margin-left: ${th('subGridUnit')};
  padding: 0 ${th('subGridUnit')};
`

// #endregion
