import React from 'react'
import styled from 'styled-components'
import { Button, th } from '@pubsweet/ui'
import { compose, withProps } from 'recompose'

import { DashboardItems, DashboardFilters } from './'

const Dashboard = ({
  dashboard,
  currentUser,
  filterItems,
  filterValues,
  deleteProject,
  dashboardItems,
  canCreateDraft,
  getFilterOptions,
  changeFilterValue,
  createDraftSubmission,
  getDefaultFilterValue,
}) => (
  <Root className="dashboard">
    <Header>
      <Heading>Manuscripts</Heading>
      <HeaderButtons>
        <Button
          data-test="new-manuscript"
          disabled={!canCreateDraft}
          onClick={createDraftSubmission}
          primary
        >
          New
        </Button>
      </HeaderButtons>
    </Header>
    <DashboardFilters
      changeFilterValue={changeFilterValue}
      getDefaultFilterValue={getDefaultFilterValue}
      getFilterOptions={getFilterOptions}
    />
    <DashboardItems deleteProject={deleteProject} list={dashboardItems} />
  </Root>
)

export default compose(
  withProps(({ dashboard, filterItems }) => ({
    dashboardItems: filterItems(dashboard.all),
  })),
)(Dashboard)

// #region styles
const Root = styled.div`
  display: flex;
  flex-direction: column;
  margin: auto;
  max-width: 60em;
  overflow: auto;
`

const Header = styled.div`
  display: flex;
  justify-content: space-between;
`

const Heading = styled.div`
  color: ${th('colorPrimary')};
  font-size: 1.6em;
  text-transform: uppercase;
`

const HeaderButtons = styled.div`
  display: flex;
`
// #endregion
