import React from 'react'
import styled from 'styled-components'
import { Menu, th } from '@pubsweet/ui'
import { compose, withHandlers } from 'recompose'

const DashboardFilters = ({
  getFilterOptions,
  changeFilterValue,
  getDefaultFilterValue,
}) => (
  <FiltersContainer>
    <span>Filter view:</span>
    <FilterGroup>
      <span>Priority</span>
      <Menu
        inline
        onChange={changeFilterValue('priority')}
        options={getFilterOptions('priority')}
        value={getDefaultFilterValue('priority')}
      />
    </FilterGroup>
    <FilterGroup>
      <span>Sort</span>
      <Menu
        inline
        onChange={changeFilterValue('order')}
        options={getFilterOptions('order')}
        value={getDefaultFilterValue('order')}
      />
    </FilterGroup>
  </FiltersContainer>
)

export default compose(
  withHandlers({
    changeFilter: ({ changeFilter }) => filterKey => value => {
      changeFilter(filterKey, value)
    },
  }),
)(DashboardFilters)

// #region styles
const FiltersContainer = styled.div`
  align-items: center;
  border-bottom: ${th('borderDefault')};
  color: ${th('colorPrimary')};
  display: flex;
  justify-content: flex-start;
  margin: calc(${th('subGridUnit')} * 2) 0;
  padding-bottom: calc(${th('subGridUnit')} * 2);

  > span {
    align-self: flex-end;
    margin-bottom: calc(${th('subGridUnit')} * 2);
    padding: 0 calc(${th('subGridUnit')});
  }
`

const FilterGroup = styled.div`
  align-items: flex-start;
  display: flex;
  flex-direction: column;
  margin-left: calc(${th('subGridUnit')} * 2);
`
// #endregion
