import { get } from 'lodash'
import PropTypes from 'prop-types'
import { connect } from 'react-redux'
import { actions } from 'pubsweet-client'
import { withJournal } from 'xpub-journal'
import { ConnectPage } from 'xpub-connect'
import { withRouter } from 'react-router-dom'
import { compose, withContext } from 'recompose'
import { newestFirst, selectCurrentUser } from 'xpub-selectors'
import { createDraftSubmission } from 'pubsweet-component-wizard/src/redux/conversion'

import {
  userNotConfirmed,
  getUserPermissions,
} from 'pubsweet-component-faraday-selectors'

import { Dashboard } from './'
import { getHandlingEditors } from '../../redux/editors'
import { priorityFilter, importanceSort, withFiltersHOC } from '../Filters'

export default compose(
  ConnectPage(() => [actions.getCollections(), actions.getUsers()]),
  connect(
    state => {
      const { collections, conversion } = state
      const currentUser = selectCurrentUser(state)
      const canCreateDraft = !userNotConfirmed(state)
      const sortedCollections = newestFirst(collections)

      const dashboard = {
        owner: sortedCollections.filter(
          collection =>
            collection.owners &&
            collection.owners.some(owner => owner.id === currentUser.id),
        ),
        reviewer: sortedCollections.filter(
          collection =>
            collection.reviewers &&
            collection.reviewers.some(
              reviewer => reviewer && reviewer.user === currentUser.id,
            ),
        ),

        all: sortedCollections,
      }
      const userPermissions = getUserPermissions(state)
      return {
        dashboard,
        conversion,
        collections,
        currentUser,
        canCreateDraft,
        userPermissions,
      }
    },
    (dispatch, { history }) => ({
      deleteProject: collection =>
        dispatch(actions.deleteCollection(collection)),
      createDraftSubmission: () => dispatch(createDraftSubmission(history)),
    }),
  ),
  ConnectPage(
    ({ currentUser }) =>
      get(currentUser, 'admin') || get(currentUser, 'editorInChief')
        ? [getHandlingEditors()]
        : [],
  ),
  withRouter,
  withJournal,
  withFiltersHOC({
    priority: priorityFilter,
    order: importanceSort,
  }),
  withContext(
    {
      journal: PropTypes.object,
      currentUser: PropTypes.object,
    },
    ({ journal, currentUser }) => ({ journal, currentUser }),
  ),
)(Dashboard)
