import React from 'react'
import { th } from '@pubsweet/ui'
import styled from 'styled-components'
import { compose, withHandlers, setDisplayName } from 'recompose'
import {
  withModal,
  ConfirmationModal,
} from 'pubsweet-component-modal/src/components'

import { handleError } from '../utils'

const DeleteManuscript = ({ confirmDelete }) => (
  <Details onClick={confirmDelete}>Delete</Details>
)

export default compose(
  setDisplayName('DeleteManuscript'),
  withModal(() => ({
    modalComponent: ConfirmationModal,
  })),
  withHandlers({
    confirmDelete: ({
      showModal,
      hideModal,
      deleteProject,
      setModalError,
    }) => () => {
      showModal({
        confirmText: 'Delete',
        title: 'Are you sure you want to delete this submission?',
        onConfirm: () => {
          deleteProject().then(hideModal, handleError(setModalError))
        },
      })
    },
  }),
)(DeleteManuscript)

// #region styled-components
const Details = styled.div`
  align-items: center;
  cursor: pointer;
  color: ${th('colorText')};
  display: flex;
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
  margin-left: calc(${th('subGridUnit')} * 2);
  text-decoration: underline;
  text-align: center;
  text-transform: uppercase;
  white-space: nowrap;
`
// #endregion
