import React from 'react'
import { get } from 'lodash'
import { th } from '@pubsweet/ui'
import styled, { css } from 'styled-components'
import { EditorInChiefActions, HandlingEditorActions } from './'

const renderHE = (currentUser, isHE, project) => {
  const status = get(project, 'status') || 'draft'
  const isAdmin = get(currentUser, 'admin')
  const isEic = get(currentUser, 'editorInChief')

  const handlingEditor = get(project, 'handlingEditor')
  const eicActionsStatuses = ['submitted', 'heInvited']
  const heActionsStatuses = ['heInvited']

  if ((isAdmin || isEic) && eicActionsStatuses.includes(status)) {
    return (
      <EditorInChiefActions
        modalKey={`eicActions-${project.id}`}
        project={project}
      />
    )
  }

  if (isHE && heActionsStatuses.includes(status)) {
    return (
      <HandlingEditorActions
        currentUser={currentUser}
        modalKey={`heActions-${project.id}`}
        project={project}
      />
    )
  }

  return <AssignedHE>{get(handlingEditor, 'name') || 'N/A'}</AssignedHE>
}

const HandlingEditorSection = ({ isHE, currentUser, project }) => (
  <Root>
    <HEText>Handling Editor</HEText>
    {renderHE(currentUser, isHE, project)}
  </Root>
)

export default HandlingEditorSection

// #region styled-components
const defaultText = css`
  color: ${th('colorText')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`
const Root = styled.div`
  display: flex;
  flex-wrap: wrap;
  flex: 1;
`

const HEText = styled.div`
  ${defaultText};
  text-transform: uppercase;
`

const AssignedHE = styled.span`
  ${defaultText};
  margin-left: calc(${th('subGridUnit')} * 3);
  text-decoration: underline;
`
// #endregion
