import React from 'react'
import qs from 'querystring'
import { Icon } from '@pubsweet/ui'
import { connect } from 'react-redux'
import { compose, withHandlers } from 'recompose'

import { Components } from './'
import { createAnchorElement, removeAnchorElement } from './utils'
import { getUserToken } from '../../../../component-faraday-selectors'

const FileDownload = ({ downloadFile }) => (
  <Components.IconButton onClick={downloadFile}>
    <Icon primary size={3}>
      download
    </Icon>
  </Components.IconButton>
)

export default compose(
  connect(state => ({
    token: getUserToken(state),
  })),
  withHandlers({
    downloadFile: ({ fileId, token, fileName = 'file' }) => () => {
      const fileURL = `${
        window.location.origin
      }/api/files/${fileId}?${qs.stringify({
        download: true,
      })}`

      const xhr = new XMLHttpRequest()
      xhr.onreadystatechange = function onXhrStateChange() {
        if (this.readyState === 4) {
          if (this.status >= 200 && this.status < 300) {
            const f = new File([this.response], fileName)

            const { a, url } = createAnchorElement(f, fileName)
            a.click()
            removeAnchorElement(a, url)
          }
        }
      }
      xhr.open('GET', fileURL)
      xhr.responseType = 'blob'
      xhr.setRequestHeader('Authorization', `Bearer ${token}`)
      xhr.send()
    },
  }),
)(FileDownload)
