import React, { Fragment } from 'react'
import { last } from 'lodash'
import { Icon, th } from '@pubsweet/ui'
import styled, { css } from 'styled-components'

import { FilePreview, FileDownload, Components } from './'

const parseFileSize = size => {
  const kbSize = size / 1000
  const mbSize = kbSize / 1000
  const gbSize = mbSize / 1000

  if (Math.floor(gbSize)) {
    return `${Math.floor(gbSize)} GB`
  } else if (Math.floor(mbSize)) {
    return `${Math.floor(mbSize)} MB`
  } else if (Math.floor(kbSize)) {
    return `${Math.floor(kbSize)} kB`
  }
  return `${size} bytes`
}

const hasPreview = (name = '') => {
  const extension = last(name.split('.'))
  return ['pdf', 'png', 'jpg'].includes(extension)
}

const FileItem = ({
  id,
  name,
  size,
  theme,
  dragHandle,
  removeFile,
  compact = false,
}) => (
  <Fragment>
    {compact ? (
      <FileRoot data-test={`file-${id}`}>
        {hasPreview(name) && <FilePreview fileId={id} />}
        <FileDownload fileId={id} fileName={name} />
        <FileName>{name}</FileName>
        <FileSize>{parseFileSize(size)}</FileSize>
        {removeFile && (
          <Components.IconButton onClick={removeFile(id)}>
            <Icon primary size={3}>
              x
            </Icon>
          </Components.IconButton>
        )}
      </FileRoot>
    ) : (
      <Root data-test={`file-${id}`}>
        {dragHandle}
        <Info>
          <span>{name}</span>
          <span>{parseFileSize(size)}</span>
        </Info>
        <Buttons>
          {hasPreview(name) && <FilePreview fileId={id} />}
          {removeFile && (
            <button onClick={removeFile(id)} title="Delete">
              <Icon primary size={3}>
                trash-2
              </Icon>
            </button>
          )}
        </Buttons>
      </Root>
    )}
  </Fragment>
)

export default FileItem

// #region styles
const defaultText = css`
  color: ${th('colorPrimary')};
  font-family: ${th('fontHeading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const Root = styled.div`
  align-items: center;
  border: ${th('borderDefault')};
  display: flex;
  margin: ${th('subGridUnit')};
`

const Info = styled.div`
  border-right: ${th('borderDefault')};
  display: flex;
  flex: 1;
  justify-content: space-between;
  padding: calc(${th('subGridUnit')} / 2) ${th('subGridUnit')}
    ${th('subGridUnit')} 0;
`

const Buttons = styled.div`
  align-items: center;
  display: flex;
  justify-content: center;
  margin: 0 calc(${th('subGridUnit')} * 2);

  a {
    align-items: center;
    display: flex;
  }

  button {
    background-color: transparent;
    border: none;
    cursor: pointer;

    &:active,
    &:focus {
      outline: none;
    }
  }
`
const FileName = styled.span`
  ${defaultText};
  margin: 0 ${th('subGridUnit')};
`
const FileSize = FileName.extend`
  margin-left: ${th('subGridUnit')};
`

const FileRoot = styled.div`
  align-items: center;
  border: ${th('borderDefault')};
  display: flex;
  flex-direction: row;
  margin-bottom: ${th('subGridUnit')};
  margin-right: ${th('subGridUnit')};
  padding: ${th('subGridUnit')};
`
// #endregion
