import React from 'react'
import { get } from 'lodash'
import { Icon } from '@pubsweet/ui'
import { connect } from 'react-redux'
import styled from 'styled-components'
import { actions } from 'pubsweet-client'
import { compose, withState, withHandlers } from 'recompose'
import { getFormValues, reset as resetForm } from 'redux-form'

import { FormItems } from '../UIComponents'
import { StepOne, StepTwo, utils } from './'
import { createRecommendation } from '../../redux/recommendations'

const RecommendWizard = ({
  step,
  decision,
  nextStep,
  prevStep,
  closeModal,
  submitForm,
  ...rest
}) => (
  <FormItems.RootContainer>
    <IconButton onClick={closeModal}>
      <Icon primary>x</Icon>
    </IconButton>
    {step === 0 && (
      <StepOne
        disabled={!decision}
        hideModal={closeModal}
        onSubmit={nextStep}
        {...rest}
      />
    )}
    {step === 1 && (
      <StepTwo decision={decision} goBack={prevStep} onSubmit={submitForm} />
    )}
  </FormItems.RootContainer>
)

export default compose(
  connect(
    state => ({
      decision: get(getFormValues('recommendation')(state), 'decision'),
    }),
    {
      resetForm,
      createRecommendation,
      getFragments: actions.getFragments,
      getCollections: actions.getCollections,
    },
  ),
  withState('step', 'changeStep', 0),
  withHandlers({
    nextStep: ({ changeStep }) => () => changeStep(s => s + 1),
    prevStep: ({ changeStep }) => () => changeStep(s => (s === 0 ? 0 : s - 1)),
    closeModal: ({ hideModal, resetForm }) => () => {
      hideModal()
      resetForm('recommendation')
    },
    submitForm: ({
      showModal,
      hideModal,
      resetForm,
      fragmentId,
      collectionId,
      getFragments,
      getCollections,
      createRecommendation,
    }) => values => {
      const recommendation = utils.parseRecommendationValues(values)
      createRecommendation(collectionId, fragmentId, recommendation).then(r => {
        resetForm('recommendation')
        showModal({
          title: 'Recommendation sent',
          cancelText: 'OK',
          onCancel: () => {
            getCollections()
            getFragments()
            hideModal()
          },
        })
      })
    },
  }),
)(RecommendWizard)

// #region styled components
const IconButton = styled.div`
  align-self: flex-end;
  cursor: pointer;
`
// #endregion
