import React from 'react'
import { connect } from 'react-redux'
import { Button } from '@pubsweet/ui'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { compose, lifecycle, withState } from 'recompose'

import { parseSearchParams } from '../utils'
import { confirmUser } from '../../redux/users'

const ConfirmAccount = ({ location, message, history }) => (
  <Root>
    <Title>{message}</Title>
    <Button onClick={() => history.replace('/')} primary>
      Go to Dashboard
    </Button>
  </Root>
)

const confirmMessage = `Your account has been successfully confirmed. Welcome to Hindawi!`
const errorMessage = `Something went wrong with your account confirmation. Please try again.`

export default compose(
  connect(null, { confirmUser }),
  withState('message', 'setConfirmMessage', 'Loading...'),
  lifecycle({
    componentDidMount() {
      const { location, confirmUser, setConfirmMessage } = this.props
      const { confirmationToken, userId } = parseSearchParams(location.search)
      if (userId) {
        confirmUser(userId, confirmationToken)
          .then(() => {
            setConfirmMessage(confirmMessage)
          })
          .catch(() => {
            // errors are still gobbled up by pubsweet
            setConfirmMessage(errorMessage)
          })
      }
    },
  }),
)(ConfirmAccount)

// #region styled components
const Root = styled.div`
  color: ${th('colorText')};
  margin: 0 auto;
  text-align: center;
  width: 70vw;

  a {
    color: ${th('colorText')};
  }
`

const Title = styled.div`
  color: ${th('colorPrimary')};
  font-size: ${th('fontSizeHeading5')};
  font-family: ${th('fontHeading')};
  margin: 10px auto;
`
// #endregion
